@@ -11,31 +11,34 @@ import java.util.ArrayList;
  *
  */
 public class AvailableCharsetList implements Serializable {
-	
+
 	private static final long serialVersionUID = -1635081144303522534L;
-	
-	protected ArrayList<String> charsetList;
-	protected String defaultCharset;
-	
-	protected AvailableCharsetList()
-	{}
-	
+
+	private ArrayList<String> charsetList;
+	private String defaultCharset;
+
+	public AvailableCharsetList() {
+		super();
+	}
+
 	/**
 	 * @param charsetList
 	 * @param defaultCharset
 	 */
-	public AvailableCharsetList(ArrayList<String> charsetList, String defaultCharset) {
+	public AvailableCharsetList(ArrayList<String> charsetList,
+			String defaultCharset) {
+		super();
 		this.charsetList = charsetList;
 		this.defaultCharset = defaultCharset;
 	}
-	
+
 	/**
 	 * @return the charsetList
 	 */
 	public ArrayList<String> getCharsetList() {
 		return charsetList;
 	}
-	
+
 	/**
 	 * @return the defaultCharset
 	 */
